countryscales-package: countryscales: Country Scales

countryscales-packageR Documentation

countryscales: Country Scales

Description

logo

Format numbers, percentages and currencies, and label 'ggplot2' axes, using country- or locale-specific conventions such as the thousands separator, decimal mark, currency symbol placement, and sign placement. Locale data is sourced from the Unicode Common Locale Data Repository (CLDR, https://cldr.unicode.org) via the 'i18n' package, covering several hundred locales in addition to dedicated helpers for Germany, Switzerland and the United States.

Author(s)

Maintainer: Stefan Moog moogs@gmx.de

Authors:

  • Stefan Moog moogs@gmx.de

  • scales authors (Authors of included code from the scales package)

Other contributors:

  • Posit, PBC (Copyright holder of included code from the scales package) [copyright holder]

See Also

Useful links:


countryscales documentation built on Sept. 29, 2026, 5:09 p.m.