| demo_number | R Documentation |
ggplot2 demo
demo_number(x, scale_name, ...)
x |
a numeric |
scale_name |
scale name |
... |
further arguments to be passed to the scale |
A ggplot object, invisibly printed as a demo of the requested
scale.
demo_number(c(32, 212), scale_name = "number_locale")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.