| countryscales-package | R Documentation |
Format numbers, percentages and currencies, and label 'ggplot2' axes, using country- or locale-specific conventions such as the thousands separator, decimal mark, currency symbol placement, and sign placement. Locale data is sourced from the Unicode Common Locale Data Repository (CLDR, https://cldr.unicode.org) via the 'i18n' package, covering several hundred locales in addition to dedicated helpers for Germany, Switzerland and the United States.
Maintainer: Stefan Moog moogs@gmx.de
Authors:
Stefan Moog moogs@gmx.de
scales authors (Authors of included code from the scales package)
Other contributors:
Posit, PBC (Copyright holder of included code from the scales package) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.